Merge branch 'refs/heads/t/format-signedness'
[paraslash.git] / fd.c
diff --git a/fd.c b/fd.c
index 3a8406d9c9fd1454a0807c8584bae78aa1b2f543..6a26ce5e3d4d5f2993affc76a544e96db1a5738c 100644 (file)
--- a/fd.c
+++ b/fd.c
@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2006-2012 Andre Noll <maan@systemlinux.org>
+ * Copyright (C) 2006 Andre Noll <maan@tuebingen.mpg.de>
  *
  * Licensed under the GPL v2. For licencing details see COPYING.
  */
 #include <sys/types.h>
 #include <dirent.h>
 #include <sys/mman.h>
-#include <fcntl.h>
-#include <sys/uio.h>
 
 #include "para.h"
 #include "error.h"
 #include "string.h"
 #include "fd.h"
 
+/**
+ * Change the name or location of a file.
+ *
+ * \param oldpath File to be moved.
+ * \param newpath Destination.
+ *
+ * This is just a simple wrapper for the rename(2) system call which returns a
+ * paraslash error code and prints an error message on failure.
+ *
+ * \return Standard.
+ *
+ * \sa rename(2).
+ */
+int xrename(const char *oldpath, const char *newpath)
+{
+       int ret = rename(oldpath, newpath);
+
+       if (ret >= 0)
+               return 1;
+       ret = -ERRNO_TO_PARA_ERROR(errno);
+       PARA_ERROR_LOG("failed to rename %s -> %s\n", oldpath, newpath);
+       return ret;
+}
+
 /**
  * Write an array of buffers to a file descriptor.
  *
@@ -146,6 +168,7 @@ __printf_2_3 int write_va_buffer(int fd, const char *fmt, ...)
 
        va_start(ap, fmt);
        ret = xvasprintf(&msg, fmt, ap);
+       va_end(ap);
        ret = write_all(fd, msg, ret);
        free(msg);
        return ret;
@@ -162,13 +185,13 @@ __printf_2_3 int write_va_buffer(int fd, const char *fmt, ...)
  *
  * If \a rfds is not \p NULL and the (non-blocking) file descriptor \a fd is
  * not set in \a rfds, this function returns early without doing anything.
- * Otherwise The function tries to read up to \a sz bytes from \a fd. As for
- * xwrite(), EAGAIN is not considered an error condition. However, EOF
- * is.
+ * Otherwise The function tries to read up to \a sz bytes from \a fd, where \a
+ * sz is the sum of the lengths of all vectors in \a iov. As for xwrite(),
+ * \p EAGAIN is not considered an error condition. However, \p EOF is.
  *
  * \return Zero or a negative error code. If the underlying call to readv(2)
  * returned zero (indicating an end of file condition) or failed for some
* reason other than \p EAGAIN, a negative return value is returned.
  *
  * In any case, \a num_bytes contains the number of bytes that have been
  * successfully read from \a fd (zero if the first readv() call failed with
@@ -526,6 +549,7 @@ static int para_opendir(const char *dirname, DIR **dir, int *cwd)
 {
        int ret;
 
+       *dir = NULL;
        if (cwd) {
                ret = para_open(".", O_RDONLY, 0);
                if (ret < 0)
@@ -162,13 +185,13 @@ __printf_2_3 int write_va_buffer(int fd, const char *fmt, ...)
  * \return Zero or a negative error code. If the underlying call to readv(2)
  * returned zero (indicating an end of file condition) or failed for some
- * reason other than \p EAGAIN, a negative return value is returned.
+ * reason other than \p EAGAIN, a negative error code is returned.
  *
  * In any case, \a num_bytes contains the number of bytes that have been